@@ -233,6 +233,16 @@ class MessageActionReportMixin(MessageContractIDMixin):
     def is_ask(self, val):
         self._is_ask = bool(val)
 
+    @MessageField
+    def clock(self):
+        if not self._clock:
+            self._clock = 0
+        return self._clock
+
+    @clock.setter
+    def clock(self, val):
+        self._clock = int(val)
+
 @record_message_type
 class MessageLimitOrder(ClientMessage, MessageSubmissionMixin):
     """\
@@ -407,6 +417,16 @@ class MessageBookState(ClientMessage, MessageContractIDMixin, MessageEntryIDMixi
     def is_end(self, val):
         self._is_end = bool(val)
 
+    @MessageField
+    def clock(self):
+        if not self._clock:
+            self._clock = 0
+        return self._clock
+
+    @clock.setter
+    def clock(self, val):
+        self._clock = int(val)
+
 @record_message_type
 class MessageBookTop(ClientMessage, MessageContractIDMixin):
     """\
